@@ -24,13 +24,12 @@ import gtk
 import pycwapi
 import time
 
-PROJECT_ROOT_DIRECTORY = os.path.abspath(
-    os.path.dirname(os.path.dirname(os.path.realpath(sys.argv[0]))))
+from base import DATA_PATH, ICON_PATH
 
 class ExtendedForecast():
     def __init__(self, forecast_data):
         self.builder = gtk.Builder()
-        self.builder.add_from_file(os.path.join(PROJECT_ROOT_DIRECTORY, 'data/ui/ExtendedForecast.ui'))
+        self.builder.add_from_file(os.path.join(DATA_PATH, 'ui/ExtendedForecast.ui'))
         self.img_ct = self.builder.get_object("img_ct")
         self.img_uv = self.builder.get_object("img_uv")
         self.img_xc = self.builder.get_object("img_xc")
@@ -38,20 +37,18 @@ class ExtendedForecast():
         self.img_cl = self.builder.get_object("img_cl")
         self.img_ls = self.builder.get_object("img_ls")
         self.img_ag = self.builder.get_object("img_ag")
-        self.img_ct.set_from_file(os.path.join(PROJECT_ROOT_DIRECTORY, 'icons/ct1.gif'))
-        self.img_uv.set_from_file(os.path.join(PROJECT_ROOT_DIRECTORY, 'icons/uv1.gif'))
-        self.img_xc.set_from_file(os.path.join(PROJECT_ROOT_DIRECTORY, 'icons/xc1.gif'))
-        self.img_tr.set_from_file(os.path.join(PROJECT_ROOT_DIRECTORY, 'icons/tr1.gif'))
-        self.img_cl.set_from_file(os.path.join(PROJECT_ROOT_DIRECTORY, 'icons/cl1.gif'))
-        self.img_ls.set_from_file(os.path.join(PROJECT_ROOT_DIRECTORY, 'icons/ls1.gif'))
-        self.img_ag.set_from_file(os.path.join(PROJECT_ROOT_DIRECTORY, 'icons/ag.jpg'))
+        self.img_ct.set_from_file(os.path.join(ICON_PATH, 'ct1.gif'))
+        self.img_uv.set_from_file(os.path.join(ICON_PATH, 'uv1.gif'))
+        self.img_xc.set_from_file(os.path.join(ICON_PATH, 'xc1.gif'))
+        self.img_tr.set_from_file(os.path.join(ICON_PATH, 'tr1.gif'))
+        self.img_cl.set_from_file(os.path.join(ICON_PATH, 'cl1.gif'))
+        self.img_ls.set_from_file(os.path.join(ICON_PATH, 'ls1.gif'))
+        self.img_ag.set_from_file(os.path.join(ICON_PATH, 'ag.jpg'))
 
         self.window = self.builder.get_object("window")
         self.builder.connect_signals(self)
         self.window.show()
         self.forecast_data = forecast_data
-        #print('forecastdate->')
-        #print(self.forecast_data)
 
         self.builder.get_object("img1").set_from_file(self.get_weather_icon('img1'))
         self.builder.get_object("img2").set_from_file(self.get_weather_icon('img2'))
@@ -89,8 +86,6 @@ class ExtendedForecast():
 
         self.time = time.strftime('%w', time.localtime(time.time()))
         #self.time = time.strftime('%Y-%m-%d', time.localtime(time.time()))
-        #print('today is :')
-        #print(self.time)
         labelofweek = ["week1", "week2", "week3", "week4", "week5", "week6"]
         dayofweek = ["星期一", "星期二", "星期三", "星期四", "星期五", "星期六", "星期天"]
         for i in range(0,6):
@@ -120,14 +115,14 @@ class ExtendedForecast():
             icons_night = ('img1', 'img3', 'img5', 'img7', 'img9', 'img11')
         if img in icons_day:
             if self.forecast_data[img] == '99':
-                return os.path.join(PROJECT_ROOT_DIRECTORY, 'icons/d') + self.forecast_data[icons_night[icons_day.index(img)]] + '.gif'
+                return os.path.join(ICON_PATH, 'd') + self.forecast_data[icons_night[icons_day.index(img)]] + '.gif'
             else:
-                return os.path.join(PROJECT_ROOT_DIRECTORY, 'icons/d') + self.forecast_data[img] + '.gif'
+                return os.path.join(ICON_PATH, 'd') + self.forecast_data[img] + '.gif'
         elif img in icons_night:
             if self.forecast_data[img] == '99':
-                return os.path.join(PROJECT_ROOT_DIRECTORY, 'icons/n') + self.forecast_data[icons_day[icons_night.index(img)]] + '.gif'
+                return os.path.join(ICON_PATH, 'n') + self.forecast_data[icons_day[icons_night.index(img)]] + '.gif'
             else:
-                return os.path.join(PROJECT_ROOT_DIRECTORY, 'icons/n') + self.forecast_data[img] + '.gif'
+                return os.path.join(ICON_PATH, 'n') + self.forecast_data[img] + '.gif'
 
 if __name__ == "__main__":
     forecast_data = pycwapi.get_weather_from_nmc(sys.argv[1], 1)
