@@ -43,12 +43,7 @@ from pm25 import *
 import gettext
 from gettext import gettext as _
 from gettext import ngettext as __
-
-VERSION = "1.0.5"
-
-# Add project root directory (enable symlink, and trunk execution).
-PROJECT_ROOT_DIRECTORY = os.path.abspath(
-    os.path.dirname(os.path.dirname(os.path.realpath(sys.argv[0]))))
+from base import VERSION, PROJECT_ROOT_DIRECTORY
 
 CHN_CITY_LIST_FILE = os.path.join(PROJECT_ROOT_DIRECTORY, 'src/location.txt')
 
@@ -150,7 +145,7 @@ class indicator_weather(threading.Thread):
         self.rate = self.settings.get_value("refresh_rate")
         self.city_change_flag = False
         if self.rate in (False, None):
-            default_value = 15
+            default_value = 60
             self.settings.set_value("refresh_rate", default_value)
             self.rate = default_value
 
@@ -164,11 +159,10 @@ class indicator_weather(threading.Thread):
         self.places = str(self.settings.get_value("places"))
         self.placechosen = self.settings.get_value("placechosen")
         self.actualization_time = 0        
+        self.pm25_flag = False
 
         #(LP: #1153468)
         if self.city_id not in (False, None, '', '[]', "['']") and self.places in (False, None, '', '[]', "['']"):
-            #self.city_id = ''
-            #self.settings.set_value("city_id", self.city_id)
             locations = get_location_from_cityid(self.city_id)
             self.places = [[self.city_id, locations]]
             self.settings.set_value("places", str(self.places))
@@ -251,11 +245,11 @@ class indicator_weather(threading.Thread):
                 self.placechosen = 0
             self.place = self.places[self.placechosen]
             self.menu_normal()
+            # when program start, it update_data 20130614
+            self.pm25_flag = True
             self.update_data()
-            #self.place = get_location_from_cityid(self.city_id)
-            #self.pm = get_pm_from_city(self.place.split(',')[2])
-        # fix bug about update time (LP: #1131556)
-        gobject.timeout_add_seconds(60,self.work)
+        # Fixed bug about update time (LP: #1131556)
+        gobject.timeout_add_seconds(60, self.work)
 
     # Show a menu if no places specified
     def menu_noplace(self):
@@ -343,12 +337,6 @@ class indicator_weather(threading.Thread):
         self.pm_show.show()
         self.menu.append(self.pm_show)
 
-        ##Update Button
-        #self.refresh_show = gtk.MenuItem()
-        #self.refresh_show.connect("activate", self.update_data)
-        #self.refresh_show.show()
-        #self.menu.append(self.refresh_show)
-
         ##Breaker
         breaker = gtk.SeparatorMenuItem()
         breaker.show()
@@ -422,6 +410,8 @@ class indicator_weather(threading.Thread):
             self.settings.set_value("placechosen", self.placechosen)
             self.city_id = self.places[self.placechosen][0]
             self.settings.set_value("city_id", self.city_id)
+            # when change city, it update_data 20130614
+            self.pm25_flag = True
             self.update_data()
 
     # Set a label of indicator
@@ -502,8 +492,9 @@ class indicator_weather(threading.Thread):
     def get_pm_info(self):
         from pycwapi import get_location_from_cityid
         try:
-            #self.place = get_location_from_cityid(self.city_id)
             self.pm = get_pm(self.place[1].split(',')[2])
+            if self.pm in (False, None, '', '[]', "['']"):
+                self.pm = {}
             if self.pm.has_key('error'):
                 self.pm_show.set_label(_('PM2.5:') + 'N/A')
             else:
@@ -528,10 +519,15 @@ class indicator_weather(threading.Thread):
     def update_data(self, widget = None):
         threading.Thread(target=self.get_set_weather, name='Weather').start()
         threading.Thread(target=self.get_forecast, name='Forecast').start()
-        threading.Thread(target=self.get_pm_info, name='PM25').start()
+        if self.pm25_flag:
+            self.pm25_flag = False
+            threading.Thread(target=self.get_pm_info, name='PM25').start()
         self.actualization_time = 0
         self.work()
 
+    # Update PM2.5 once every 6 hours when automatic updates
+    def only_update_pm25(self, widget = None):
+        threading.Thread(target=self.get_pm_info, name='PM25').start()
 
     # Menu callbacks
     # Open Preferences dialog
@@ -579,9 +575,10 @@ class indicator_weather(threading.Thread):
         else:
             self.rate_id = gobject.timeout_add(
                 int(self.rate) * 60000, self.update_data)
+            # Update PM2.5 once every 6 hours(LP: #1190910)
+            gobject.timeout_add(360 * 60000, self.only_update_pm25)
 
     def forecast(self, widget):
-        #self.get_forecast()
         self.forecastwd = forecastui.ExtendedForecast(self.forecast_data)
 
 class PreferencesDialog(gtk.Dialog):
@@ -687,6 +684,8 @@ class PreferencesDialog(gtk.Dialog):
             need_to_update = True
 
         if need_to_update:
+            # when add city, it update_data 20130614
+            iw.pm25_flag = True
             iw.update_data()
         self.destroy()
 
@@ -793,16 +792,14 @@ class Assistant(gtk.Assistant):
             newplace.append(self.context)#Label
             newplace.append(self.cityid)#City
             newplace.append(self.cityid)#details
-            #iw.pm = get_pm_from_city(iw.place.split(',')[2])
             item = iw.prefswindow.builder.get_object('citieslist').get_iter_first()
-            #iw.prefswindow.builder.get_object('citieslist').clear()
             iw.prefswindow.builder.get_object('citieslist').append(newplace)
 
         # Enable 'OK' button in Preferences
         iw.prefswindow.builder.get_object('ok_button').set_sensitive(True)
         self.hide()
 
-#ensure that single instance of applet is running for each user
+# ensure that single instance of applet is running for each user
 class SingleInstance(object):
     
     #Initialize, specifying a path to store pids
@@ -839,9 +836,7 @@ class SingleInstance(object):
             log.debug("SingleInstance: deleting %s" % self.pidPath)
             os.unlink(self.pidPath)
 
-
 def main():
-
     gtk.main()
     return 0
 
@@ -860,9 +855,7 @@ if __name__ == "__main__":
     log_handler.setFormatter(log_formatter)
     log.addHandler(log_handler)
 
-    log.info("------------------------------")
-    #log.info("Started Weather Indicator from %s" % PROJECT_ROOT_DIRECTORY)
-    #log.info("Weather Indicator version %s" % VERSION)
+    log.info("-------Started Indicator China Weather from %s --------" % PROJECT_ROOT_DIRECTORY)
 
     # Single instance stuff for weather indicator
     myapp = SingleInstance("/tmp/indicator-china-weather-%d.pid" % os.getuid())
