@@ -27,15 +27,7 @@ import os, sys
 import urllib2, urllib
 import json
 
-CHN_WEATHER_URL_SIMPLE1 = 'http://www.weather.com.cn/data/sk/%s.html'
-CHN_WEATHER_URL_SIMPLE2 = 'http://www.weather.com.cn/data/cityinfo/%s.html'
-CHN_WEATHER_URL_COMPLEX = 'http://m.weather.com.cn/data/%s.html'
-
-CHN_WEATHER_ICON_URL_DAY = 'http://www.weather.com.cn/m/i/weatherpic/29x20/%s'
-CHN_WEATHER_ICON_URL_NIGHT = 'http://www.weather.com.cn/m2/i/icon_weather/29x20/%s'
-
-PROJECT_ROOT_DIRECTORY = os.path.abspath(
-    os.path.dirname(os.path.dirname(os.path.realpath(sys.argv[0]))))
+from base import PROJECT_ROOT_DIRECTORY, WEATHER_URL, WEATHER_URL1, WEATHER_URL2
 
 CHN_CITY_LIST_FILE = os.path.join(PROJECT_ROOT_DIRECTORY, 'src/location.txt')
 
@@ -60,8 +52,8 @@ def get_weather_from_nmc(location_id, method = 0):
     """
     weather_data = {}
     if method == 0:
-        url1 = CHN_WEATHER_URL_SIMPLE1 % (location_id)
-        url2 = CHN_WEATHER_URL_SIMPLE2 % (location_id)
+        url1 = WEATHER_URL1 % (location_id)
+        url2 = WEATHER_URL2 % (location_id)
         json_string1 = read_from_url(url1)
         json_string2 = read_from_url(url2)
         parsed_json1 = json.loads(json_string1)
@@ -71,7 +63,7 @@ def get_weather_from_nmc(location_id, method = 0):
         for key in ('weather', 'temp1', 'temp2', 'img1', 'img2', 'ptime'):
             weather_data[key] = parsed_json2['weatherinfo'][key]
     elif method == 1:
-        url = CHN_WEATHER_URL_COMPLEX % (location_id)
+        url = WEATHER_URL % (location_id)
         json_string = read_from_url(url)
         parsed_json = json.loads(json_string)
         tp_forecast = ('city', 'date_y', 'fchh', 'temp1', 'temp2', 'temp3', 'temp4', 'temp5', 'temp6', \
@@ -105,8 +97,4 @@ def get_location_from_cityid(cityid):
 if __name__ == "__main__":
     weatherinfo = get_weather_from_nmc('101281601', 0)
     cities = get_cities_from_localfile('长沙')
-    print cities
-    print weatherinfo
     download_icon_from_nmc('d0.gif', 'd')
-
-
